@@ -376,3 +376,18 @@ def probability_in_interval(uncertain_value, interval):
     upper_bound = interval[1]
     return sum((lower_bound < samples) & (samples < upper_bound)) \
         / len(samples)
+
+
+def from_data(data_list):
+    """ Generates an UncertainValue object from a list with numbers, assuming
+        a normal distribution
+
+    Args:
+        data_list (list/np.array): 1D array with real numbers
+
+    Returns:
+        UncertainValue: uncertain number with the same mean and standard
+            deviation as the input data_list
+    """
+    return UncertainValue(np.average(data_list), -np.inf, np.inf, 'normal',
+                          [np.average(data_list), np.std(data_list)])
